@@ -1,7 +1,7 @@
-require File.join(File.dirname(__FILE__), "test_helper")
-require File.join(File.dirname(__FILE__), '..', 'lib', 'timecop')
+require_relative "test_helper"
+require 'timecop'
 
-class TestTimecopWithoutDate < Minitest::Unit::TestCase
+class TestTimecopWithoutDate < Minitest::Test
 
   def setup
     Object.send(:remove_const, :Date) if Object.const_defined?(:Date)
@@ -70,7 +70,7 @@ class TestTimecopWithoutDate < Minitest::Unit::TestCase
       new_now = Time.now
       assert_times_effectively_equal new_now, t, 1, "Looks like we failed to actually travel time" # 0.1 seconds
       sleep(0.25)
-      assert_times_effectively_not_equal new_now, Time.now, 0.25, "Looks like time is not moving"
+      assert_times_effectively_not_equal new_now, Time.now, 0.24, "Looks like time is not moving"
     end
   end
 
